@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2005-2010 Thierry FOURNIER
- * $Id: loadconfig.c 508 2007-06-07 09:12:02Z thierry $
+ * $Id: loadconfig.c 667 2007-11-17 14:26:13Z  $
  *
  */
 
@@ -27,6 +27,7 @@ char lowercase(char);
 int convert_octal(char*);
 int convert_int(char*);
 int convert_boolean(char*);
+int end_of_conf = 0;
 
 void usage(){
 	printf(
@@ -42,6 +43,7 @@ void usage(){
 	"    -e script:    script executed whith alerts\n"
 	"    -D loglevel:  loglevel (0 to 7)\n"
 	"    -l leases:    file to store mac addresses\n"
+	"    -m module:    module file to load\n"
 	"    -d:           run as daemon\n"
 	"    -F:           run in foreground\n"
 	"    -v:           dump config\n"
@@ -424,6 +426,18 @@ void config_load(int argc, char *argv[]){
 					config[CF_LEASES].valeur.string = strdup(argv[i]);
 					break;
 	
+				case 'm':
+					if(i+1 >= argc){
+						logmsg(LOG_ERR, "Option -m without argument");
+						usage();
+					}
+					i++;
+					if(config[CF_MOD_ALERT].valeur.string != NULL){
+						free(config[CF_MOD_ALERT].valeur.string);
+					}
+					config[CF_MOD_ALERT].valeur.string = strdup(argv[i]);
+					break;
+
 				case 'v':
 					dump = 1;
 					break;
@@ -766,3 +780,37 @@ void miseenforme(char *params){
 	}
 }
 
+void set_end_of_conf(void) {
+	end_of_conf = 1;
+}
+
+void set_option(int opt, void *value) {
+	if ( end_of_conf == 1 ) {
+		logmsg(LOG_ALERT, "can not modify config");
+		return;
+	}
+
+	// check for unauthorized options
+	switch (opt) {
+		case CF_MOD_ALERT:
+		case CF_MOD_CONFIG:
+		case CF_USESYSLOG:
+		case CF_LOGFILE:
+			logmsg(LOG_ALERT, "can not modify config option %d", opt);
+			return;
+	}
+
+	switch ( config[opt].type ) {
+		case 0:
+			if ( value == NULL ) {
+				config[opt].valeur.string = NULL;
+			} else {
+				config[opt].valeur.string = strdup((char *)value);
+			}
+			break;
+		case 1:
+		case 2:
+			config[opt].valeur.integer = (int)value;
+			break;
+	}
+}
