@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2005-2010 Thierry FOURNIER
- * $Id: loadconfig.h 508 2007-06-07 09:12:02Z thierry $
+ * $Id: loadconfig.h 667 2007-11-17 14:26:13Z  $
  *
  */
 
@@ -130,4 +130,7 @@ char config_file[CONFIGFILE_LEN];
 // load config file values
 void config_load(int, char **);
 
+// can not modify config
+void set_end_of_conf(void);
+
 #endif
