@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2005-2010 Thierry FOURNIER
- * $Id: loadmodule.c 508 2007-06-07 09:12:02Z  $
+ * $Id: loadmodule.c 667 2007-11-17 14:26:13Z  $
  *
  */
 
@@ -88,6 +88,9 @@ void module_load(void){
 
 	// module initialisation call
 	if(mod_load != NULL) mod_load(config[CF_MOD_CONFIG].valeur.string);
+
+	// can not modify config
+	set_end_of_conf();
 }
 
 // unload and close module
@@ -134,7 +137,7 @@ void alerte_mod(struct ether_addr *mac_sender,
 
 	args[0] = (void *)interface;
 	args[1] = (void *)mac_sender;
-	args[2] = (void *)&ip_sender;
+	args[2] = (void *)ip_sender.s_addr;
 	switch(type){
 		case 0:
 		case 4:
