@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2005-2010 Thierry FOURNIER
- * $Id: log.c 508 2007-06-07 09:12:02Z thierry $
+ * $Id: log.c 667 2007-11-17 14:26:13Z  $
  *
  */
 
@@ -26,7 +26,7 @@
 
 extern int errno;
 
-FILE *lf;
+FILE *lf = NULL;
 const char *mois[12] = {
 	"Jan",
 	"Feb",
@@ -45,6 +45,10 @@ const char *mois[12] = {
 int syslog_initialized = FALSE;
 int file_initialized = FALSE;
 
+// used for compose log
+#define LOG_MAX_SIZE 512
+char log_msg[LOG_MAX_SIZE];
+
 void initlog(void){
 	#ifdef USE_SYSLOG
 	if(config[CF_USESYSLOG].valeur.integer == TRUE){
@@ -66,9 +70,38 @@ void initlog(void){
 	file_initialized = TRUE;
 }
 
+void logfile_reload(void) {
+	int ret_code;
+
+	// check if logfile is used
+	if(config[CF_LOGFILE].valeur.string == NULL ||
+	   config[CF_LOGFILE].valeur.string[0] == '\0') {
+		return;
+	}
+
+	// if opened, close
+	if (lf != NULL) {
+		ret_code = fclose(lf);
+		if (ret_code != 0) {
+			logmsg(LOG_ERR, "[%s %d] fclose(%s): %s",
+			       __FILE__, __LINE__,
+			       config[CF_LOGFILE].valeur.string,
+			       strerror(errno));
+		}
+	}
+
+	// open logs
+	lf = fopen(config[CF_LOGFILE].valeur.string, "a");
+	if(lf == NULL){
+		logmsg(LOG_ERR, "[%s %d] fopen[%d] (%s): %s",
+		       __FILE__, __LINE__,
+		       errno, config[CF_LOGFILE].valeur.string,
+		       strerror(errno));
+	}
+}
+
 void logmsg(int priority, const char *fmt, ...){
 	va_list ap;
-	char msg[4096];
 	struct tm *tm;
 
 	// check if I do log this priority
@@ -80,13 +113,13 @@ void logmsg(int priority, const char *fmt, ...){
 	tm = localtime((time_t *)(&current_t.tv_sec));
 
 	va_start(ap, fmt);
-	vsnprintf(msg, 4096, fmt, ap);
+	vsnprintf(log_msg, LOG_MAX_SIZE, fmt, ap);
 	va_end(ap);
 
 	#ifdef USE_SYSLOG
 	if(config[CF_USESYSLOG].valeur.integer == TRUE &&
 	   syslog_initialized == TRUE){
-		syslog(priority, msg); 
+		syslog(priority, log_msg); 
 	}
 	#endif
 
@@ -100,7 +133,7 @@ void logmsg(int priority, const char *fmt, ...){
 		        tm->tm_min,
 		        tm->tm_sec, 
 		        //for year: tm->tm_year+1900,
-		        msg);
+		        log_msg);
 		fflush(lf);
 	}
 
@@ -111,7 +144,7 @@ void logmsg(int priority, const char *fmt, ...){
 		        tm->tm_hour,
 		        tm->tm_min,
 		        tm->tm_sec, 
-		        msg);
+		        log_msg);
 	}
 }
 
