@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2005-2010 Thierry FOURNIER
- * $Id: log.h 508 2007-06-07 09:12:02Z thierry $
+ * $Id: log.h 667 2007-11-17 14:26:13Z  $
  *
  */
 
@@ -22,6 +22,9 @@
 // send init and open syslog before chrooting
 void initlog(void);
 
+// rotate log file
+void logfile_reload(void);
+
 // send log message
 void logmsg(int, const char *, ...);
 
